#!  /usr/local/bin/perl
#  This program reads the witty worm interval files and produces a
#  cuttlefish configuration file.
use Getopt::Std;
use FindBin qw($Bin);
use lib "$Bin/../lib";
#use Util;

use strict;
my ($exicutable) = ($0 =~ /([^\/]+)$/);
my $usage = 
"usage:$0 [-h] witty-interval-file\n";
sub Help() {
    print STDERR $usage;
print<<EOP;
    This reads in the witty worm interval files to produce 
    a cuttlefish input file.
    h - this message
EOP
}

my %opts;
if (!getopts("h",\%opts) && !defined $opts{h}) {
    print STDERR $usage;
    exit -1;
}
if (defined $opts{h}) {
    Help();
    exit(0);
}

my %loc2id;
my %time2id2value;
my %time2total;
LoadIntervals(@ARGV);
PrintHeader();
PrintNodes();
PrintFrames();

sub LoadIntervals {
    my @files = @_;
    my $id_counter = 0;
my $file_id = 0;
    foreach my $file (@files) {
#print "processing file$file\n";
	my $time;
	my $linenum = 0;
	open (IN, "<$file") || die("Unble to open \"$file\":$!");
	while (<IN>) {
#print;
	    $linenum++;
	    if (/# (\d+)/) {
		$time = $1;
	    }
	    s/#.*//;
	    next unless (/[^\s]/);
	    my ($lat, $long, $value) = split /\s+/;
	    if ($value =~ /^\d+$/) {
		my $loc = "$lat $long";
		unless (defined $time) {
		    chop;
		    die("$file\[$linenum\] $_\n\tfailed to find time");
		}
		my $id = $loc2id{$loc};
		unless (defined $id) {
		    $loc2id{$loc} = $id_counter++;
		    $id = $loc2id{$loc};
		}
#print "time:$time id:$id\n";
		$time2id2value{$time}{$id} = $value;
		$time2total{$time} += $value;
	    }
#last if ($linenum > 10);
	}
#last if ($file_id++ > 10);
    }
}

sub PrintFrames() {
    print "# frames ------------------------------------\n";
    foreach my $time (sort {$a<=>$b} keys %time2id2value) {
print STDERR "total:$time ",$time2total{$time},"\n";
	print "object:frame time:$time\n";
	foreach my $id (sort {$a<=>$b} keys %{$time2id2value{$time}}) {
	    my $value = $time2id2value{$time}{$id};
	    print "$id $value\n";
	}
    }
}

sub PrintNodes() {
    print "# nodes ------------------------------------\n";
    print "object:nodes\n";
    foreach my $loc (sort {$loc2id{$a}<=>$loc2id{$b}} keys %loc2id) {
	my $id = $loc2id{$loc};
	print "$id $loc\n";
    }
}

sub PrintHeader {
print<<EOP;
object:global
output:witty-hosts.gif
frame-rate:1
delay:60
night-color: 0 0 0
background-color: 75 75 75
day-color: 200 200 200

# World image ------------------------------------
object:map
label: x:20 y:20 font:giant Witty Worm Hosts
label: x:20 y:30 type:date
image:images/world-water.jpg
x: 0
y: 0
image-geo: -180 -90 180 90
width:700

# Histogram -------------------------------------
object:histogram
x: 700
y: 0
y-axis: number of hosts
width: 300
height: 150

# Legend -----------------------------------
object:legend
x: 700
y: 170
y-axis: number of hosts
height: 150
EOP
}
